:mod:`langacore.kit.django.common.models`
=========================================


.. automodule:: langacore.kit.django.common.models


Classes
--------

.. autoclass:: Named
   :show-inheritance:
   :members:
   

.. autoclass:: TimeTrackable
   :show-inheritance:
   :members:
   

.. autoclass:: DisplayCounter
   :show-inheritance:
   :members:
   

.. autoclass:: SoftDeletable
   :show-inheritance:
   :members:
   

.. autoclass:: ViewableSoftDeletableManager
   :show-inheritance:
   :members:


.. autoclass:: MassMailer
   :show-inheritance:
   :members:
